@@ -24,12 +24,13 @@ class Users(ApiResource):
             'branch': self.branch,
         })
 
-    def check(self, user_id, action, resource_id, resource_type):
+    def check(self, user_id, action, resource_id, resource_type, attribute=''):
         return self.dispatch('/v1/grants', HttpMethods.GET, {
             'id': user_id,
             'action': action,
             'resource_type': resource_type,
             'resource_id': resource_id,
+            'attribute': attribute,
             'branch': self.branch,
         })
 
@@ -39,7 +40,7 @@ class Users(ApiResource):
             'branch': self.branch,
         })
 
-    def grant_action(self, user_id, action, resource_id, resource_type):
+    def grant_action(self, user_id, action, resource_id, resource_type, attribute=''):
         return self.dispatch('/v1/grants', HttpMethods.POST, {
             'id': user_id,
             'subject_type': 'USER',
@@ -47,16 +48,19 @@ class Users(ApiResource):
             'relation_type': 'ACTION',
             'resource_type': resource_type,
             'resource_id': resource_id,
+            'attribute': attribute,
             'branch': self.branch,
         })
 
-    def revoke_action(self, user_id, action, resource_id, resource_type):
+    def revoke_action(self, user_id, action, resource_id, resource_type, attribute=''):
         return self.dispatch('/v1/grants', HttpMethods.DELETE, {
             'id': user_id,
             'subject_type': 'USER',
             'relation': action,
+            'relation_type': 'ACTION',
             'resource_type': resource_type,
             'resource_id': resource_id,
+            'attribute': attribute,
             'branch': self.branch,
         })
 
@@ -76,6 +80,7 @@ class Users(ApiResource):
             'id': user_id,
             'subject_type': 'USER',
             'relation': role_id,
+            'relation_type': 'ROLE',
             'resource_type': resource_type,
             'resource_id': resource_id,
             'branch': self.branch,
