@@ -8,12 +8,13 @@ from vista_api_client.api_resources.usersets import Usersets
 from vista_api_client.config.config import config
 
 class VistaClient(object):
-    def __init__(self, secret, branch, hostname=None):
-        if not hostname:
-            hostname = config['VistaAPIHostname']
+    ALL = '*'
 
-        self.admin = Admin(secret, branch, hostname)
-        self.resource_types = ResourceTypes(secret, branch, hostname)
-        self.roles = Roles(secret, branch, hostname)
-        self.users = Users(secret, branch, hostname)
-        self.usersets = Usersets(secret, branch, hostname)
+    def __init__(self, secret, branch, hostname=None):
+        self.hostname = hostname or config['VistaAPIHostname']
+
+        self.admin = Admin(secret, branch, self.hostname)
+        self.resource_types = ResourceTypes(secret, branch, self.hostname)
+        self.roles = Roles(secret, branch, self.hostname)
+        self.users = Users(secret, branch, self.hostname)
+        self.usersets = Usersets(secret, branch, self.hostname)
